@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python3
 # Copyright 2016 The Emscripten Authors.  All rights reserved.
 # Emscripten is available under two separate licenses, the MIT license and the
 # University of Illinois/NCSA Open Source License.  Both these licenses can be
@@ -23,7 +23,7 @@ generate JavaScript.
 
 from __future__ import print_function
 import sys
-from tools import shared
+from tools import building
 from subprocess import CalledProcessError
 
 
@@ -32,19 +32,17 @@ from subprocess import CalledProcessError
 #
 def run():
   if len(sys.argv) < 2 or sys.argv[1] in ('--version', '--help'):
-    print('''
-  emmake is a helper for make, setting various environment
-  variables so that emcc etc. are used. Typical usage:
+    print('''\
+emmake is a helper for make, setting various environment
+variables so that emcc etc. are used. Typical usage:
 
-    emmake make [FLAGS]
+  emmake make [FLAGS]
 
-  (but you can run any command instead of make)
-
-  ''', file=sys.stderr)
+(but you can run any command instead of make)''', file=sys.stderr)
     return 1
 
   try:
-    shared.Building.make(sys.argv[1:])
+    building.make(sys.argv[1:])
   except CalledProcessError as e:
     return e.returncode
 
