@@ -1,7 +1,8 @@
-// Copyright 2018 The Emscripten Authors.  All rights reserved.
-// Emscripten is available under two separate licenses, the MIT license and the
-// University of Illinois/NCSA Open Source License.  Both these licenses can be
-// found in the LICENSE file.
+/**
+ * @license
+ * Copyright 2018 The Emscripten Authors
+ * SPDX-License-Identifier: MIT
+ */
 
 mergeInto(LibraryManager.library, {
   $NODERAWFS__deps: ['$ERRNO_CODES', '$FS', '$NODEFS'],
@@ -70,11 +71,11 @@ mergeInto(LibraryManager.library, {
         return VFS.llseek(stream, offset, whence);
       }
       var position = offset;
-      if (whence === 1) {  // SEEK_CUR.
+      if (whence === {{{ cDefine('SEEK_CUR') }}}) {
         position += stream.position;
-      } else if (whence === 2) {  // SEEK_END.
+      } else if (whence === {{{ cDefine('SEEK_END') }}}) {
         position += fs.fstatSync(stream.nfd).size;
-      } else if (whence !== 0) {  // SEEK_SET.
+      } else if (whence !== {{{ cDefine('SEEK_SET') }}}) {
         throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
       }
 
