@@ -624,7 +624,7 @@ function abort(what) {
   throw e;
 }
 
-var memoryInitializer = null;
+// {{MEM_INITIALIZER}}
 
 #include "memoryprofiler.js"
 
@@ -834,7 +834,7 @@ function createWasm() {
     var exports = instance.exports;
 
 #if RELOCATABLE
-    exports = relocateExports(exports, GLOBAL_BASE);
+    exports = relocateExports(exports, {{{ GLOBAL_BASE }}});
 #endif
 
 #if ASYNCIFY
@@ -991,6 +991,8 @@ function createWasm() {
         Promise.all([response.clone().arrayBuffer(), result]).then(function (results) {
           wasmOffsetConverter = new WasmOffsetConverter(new Uint8Array(results[0]), results[1].module);
           {{{ runOnMainThread("removeRunDependency('offset-converter');") }}}
+        }, function(reason) {
+          err('failed to initialize offset-converter: ' + reason);
         });
 #endif
         return result.then(receiveInstantiatedSource, function(reason) {
