@@ -438,8 +438,9 @@ def llvm_backend_args():
     allowed = ','.join(Settings.EXCEPTION_CATCHING_ALLOWED or ['__fake'])
     args += ['-emscripten-cxx-exceptions-allowed=' + allowed]
 
-  # asm.js-style setjmp/longjmp handling
-  args += ['-enable-emscripten-sjlj']
+  if Settings.SUPPORT_LONGJMP:
+    # asm.js-style setjmp/longjmp handling
+    args += ['-enable-emscripten-sjlj']
 
   # better (smaller, sometimes faster) codegen, see binaryen#1054
   # and https://bugs.llvm.org/show_bug.cgi?id=39488
@@ -1003,7 +1004,7 @@ def closure_compiler(filename, pretty=True, advanced=True, extra_closure_args=No
 
     args = ['--compilation_level', 'ADVANCED_OPTIMIZATIONS' if advanced else 'SIMPLE_OPTIMIZATIONS']
     # Keep in sync with ecmaVersion in tools/acorn-optimizer.js
-    args += ['--language_in', 'ECMASCRIPT_2018']
+    args += ['--language_in', 'ECMASCRIPT_2020']
     # Tell closure not to do any transpiling or inject any polyfills.
     # At some point we may want to look into using this as way to convert to ES5 but
     # babel is perhaps a better tool for that.
@@ -1288,12 +1289,6 @@ def wasm2js(js_file, wasm_file, opt_level, minify_whitespace, use_closure_compil
   # JS optimizations
   if opt_level >= 2:
     passes = []
-    # it may be useful to also run: simplifyIfs, registerize, asmLastOpts
-    # passes += ['simplifyExpressions'] # XXX fails on wasm3js.test_sqlite
-    # TODO: enable name minification with pthreads. atm wasm2js emits pthread
-    # helper functions outside of the asmFunc(), and they mix up minifyGlobals
-    # (which assumes any vars in that area are global, like var HEAP8, but
-    # those helpers have internal vars in a scope it doesn't understand yet)
     if not debug_info and not Settings.USE_PTHREADS:
       passes += ['minifyNames']
     if minify_whitespace:
@@ -1404,6 +1399,11 @@ def instrument_js_for_asan(js_file):
   return acorn_optimizer(js_file, ['asanify'])
 
 
+def instrument_js_for_safe_heap(js_file):
+  logger.debug('instrumenting JS memory accesses for SAFE_HEAP')
+  return acorn_optimizer(js_file, ['safeHeap'])
+
+
 def handle_final_wasm_symbols(wasm_file, symbols_file, debug_info):
   logger.debug('handle_final_wasm_symbols')
   args = []
@@ -1574,16 +1574,12 @@ def run_binaryen_command(tool, infile, outfile=None, args=[], debug=False, stdou
       # emit some extra helpful text for common issues
       extra = ''
       # a plain -O0 build *almost* doesn't need post-link changes, except for
-      # legalization and longjmp. show a clear error for those (as the flags
-      # the user passed in are not enough to see what went wrong)
+      # legalization. show a clear error for those (as the flags the user passed
+      # in are not enough to see what went wrong)
       if shared.Settings.LEGALIZE_JS_FFI:
         extra += '\nnote: to disable int64 legalization (which requires changes after link) use -s WASM_BIGINT'
-      if shared.Settings.SUPPORT_LONGJMP:
-        extra += '\nnote: to disable longjmp support (which requires changes after link) use -s SUPPORT_LONGJMP=0'
       if shared.Settings.OPT_LEVEL > 0:
         extra += '\nnote: -O2+ optimizations always require changes, build with -O0 or -O1 instead'
-      if shared.Settings.DISABLE_EXCEPTION_CATCHING != 1:
-        extra += '\nnote: C++ exceptions always require changes'
       exit_with_error('changes to the wasm are required after link, but disallowed by ERROR_ON_WASM_CHANGES_AFTER_LINK: ' + str(cmd) + extra)
   if debug:
     cmd += ['-g'] # preserve the debug info
